| asselin | R Documentation |
This mode estimator is based on the algorithm described in Asselin de Beauville (1978).
asselin(x, bw = NULL, ...)
x |
numeric. Vector of observations. |
bw |
numeric. A number in |
... |
further arguments to be passed to the |
A numeric value is returned, the mode estimate.
The user may call asselin through
mlv(x, method = "asselin", ...).
Asselin de Beauville J.-P. (1978). Estimation non parametrique de la densite et du mode, exemple de la distribution Gamma. Revue de Statistique Appliquee, 26(3):47-70.
mlv for general mode estimation.
x <- rbeta(1000, shape1 = 2, shape2 = 5)
## True mode:
betaMode(shape1 = 2, shape2 = 5)
## Estimation:
asselin(x, bw = 1)
asselin(x, bw = 1/2)
mlv(x, method = "asselin")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.