distrMode: Mode of some continuous and discrete distributions

View source: R/distrMode.R

distrModeR Documentation

Mode of some continuous and discrete distributions

Description

These functions return the mode of the main probability distributions implemented in R.

Usage

distrMode(x, ...)

betaMode(shape1, shape2, ncp = 0L)

cauchyMode(location = 0, ...)

chisqMode(df, ncp = 0L)

dagumMode(scale = 1, shape1.a, shape2.p)

expMode(...)

fMode(df1, df2)

fiskMode(scale = 1, shape1.a)

frechetMode(location = 0, scale = 1, shape = 1, ...)

gammaMode(shape, rate = 1, scale = 1/rate)

normMode(mean = 0, ...)

gevMode(location = 0, scale = 1, shape = 0, ...)

ghMode(alpha = 1, beta = 0, delta = 1, mu = 0, lambda = -0.5)

ghtMode(beta = 0.1, delta = 1, mu = 0, nu = 10)

gldMode(lambda1 = 0, lambda2 = -1, lambda3 = -0.125, lambda4 = -0.125)

gompertzMode(scale = 1, shape)

gpdMode(location = 0, scale = 1, shape = 0)

gumbelMode(location = 0, ...)

hypMode(alpha = 1, beta = 0, delta = 1, mu = 0, pm = c(1L, 2L, 3L, 4L))

koenkerMode(location = 0, ...)

kumarMode(shape1, shape2)

laplaceMode(location = 0, ...)

logisMode(location = 0, ...)

lnormMode(meanlog = 0, sdlog = 1)

lomaxMode(...)

maxwellMode(rate)

mvnormMode(mean, ...)

nakaMode(scale = 1, shape)

nigMode(alpha = 1, beta = 0, delta = 1, mu = 0)

paralogisticMode(scale = 1, shape1.a)

paretoMode(scale = 1, ...)

rayleighMode(scale = 1)

stableMode(alpha, beta, gamma = 1, delta = 0, pm = 0, ...)

stableMode2(loc, disp, skew, tail)

tMode(df, ncp)

unifMode(min = 0, max = 1)

weibullMode(shape, scale = 1)

yulesMode(...)

bernMode(prob)

binomMode(size, prob)

geomMode(...)

hyperMode(m, n, k, ...)

nbinomMode(size, prob, mu)

poisMode(lambda)

Arguments

x

character. The name of the distribution to consider.

...

Additional parameters.

shape1, shape2

non-negative parameters of the Beta distribution.

ncp

non-centrality parameter.

location, scale

location and scale parameters.

df

degrees of freedom (non-negative, but can be non-integer).

shape1.a, shape2.p

shape parameters.

df1, df2

degrees of freedom. Inf is allowed.

shape

the shape parameter \xi.

rate

vector of rates.

mean

vector of means.

alpha

first shape parameter.

beta

second shape parameter, should in the range (0, alpha).

delta

scale parameter, must be zero or positive.

mu

location parameter, by default 0.

lambda

defines the sublclass, by default -1/2.

nu

a numeric value, the number of degrees of freedom. Note, alpha takes the limit of abs(beta), and lambda=-nu/2.

lambda1

location parameter.

lambda2

scale parameter.

lambda3

first shape parameter.

lambda4

second shape parameter.

pm

an integer value between 1 and 4 for the selection of the parameterization. The default takes the first parameterization.

meanlog, sdlog

mean and standard deviation of the distribution on the log scale with default values of 0 and 1 respectively.

gamma

scale parameter.

loc

vector of (real) location parameters.

disp

vector of (positive) dispersion parameters.

skew

vector of skewness parameters (in [-1,1]).

tail

vector of parameters (in [1,2]) related to the tail thickness.

min, max

lower and upper limits of the distribution. Must be finite.

prob

Probability of success on each trial.

size

number of trials (zero or more).

m

the number of white balls in the urn.

n

number of observations. If length(n) > 1, the length is taken to be the number required.

k

the number of balls drawn from the urn, hence must be in 0,1,\dots, m+n.

Value

A numeric value is returned, the (true) mode of the distribution.

Note

Some functions like normMode or cauchyMode, which relate to symmetric distributions, are trivial, but are implemented for the sake of exhaustivity.

Author(s)

ghMode and ghtMode are from package fBasics; hypMode was written by David Scott; gldMode, nigMode and stableMode were written by Diethelm Wuertz.

See Also

mlv for the estimation of the mode; the documentation of the related distributions Beta, GammaDist, etc.

Examples

## Beta distribution
curve(dbeta(x, shape1 = 2., shape2 = 3.1),
      xlim = c(0., 1.), ylab = "Beta density")
M <- betaMode(shape1 = 2., shape2 = 3.1)
abline(v = M, col = 2L)
mlv("beta", shape1 = 2., shape2 = 3.1)

## Lognormal distribution
curve(stats::dlnorm(x, meanlog = 3, sdlog = 1.1),
      xlim = c(0, 10), ylab = "Lognormal density")
M <- lnormMode(meanlog = 3, sdlog = 1.1)
abline(v = M, col = 2)
mlv("lnorm", meanlog = 3, sdlog = 1.1)


curve(VGAM::dpareto(x, scale = 1, shape = 1), xlim = c(0, 10))
abline(v = paretoMode(scale = 1), col = 2)

## Poisson distribution
poisMode(lambda = 6.)
poisMode(lambda = 6.1)
mlv("poisson", lambda = 6.1)


modeest documentation built on Sept. 21, 2026, 1:06 a.m.