| naive | R Documentation |
This estimator, also called the naive mode estimator, is defined as the center of the interval of given length containing the most observations. It is identical to Parzen's kernel mode estimator, when the kernel is chosen to be the uniform kernel.
naive(x, bw = 0.5)
x |
numeric. Vector of observations. |
bw |
numeric. The smoothing bandwidth to be used. Should belong to (0, 1). See below. |
A numeric vector is returned, the mode estimate,
which is the center of the interval of length 2*bw
containing the most observations.
The user may call naive through
mlv(x, method = "naive", bw).
Chernoff H. (1964). Estimation of the mode. Ann. Inst. Statist. Math., 16:31-41.
Leclerc J. (1997). Comportement limite fort de deux estimateurs du mode : le shorth et l'estimateur naif. C. R. Acad. Sci. Paris, Serie I, 325(11):1207-1210.
mlv for general mode estimation;
parzen for Parzen's kernel mode estimation.
# Unimodal distribution
x <- rf(10000, df1 = 40, df2 = 30)
## True mode
fMode(df1 = 40, df2 = 30)
## Estimate of the mode
mean(naive(x, bw = 1/4))
mlv(x, method = "naive", bw = 1/4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.